import { useState, useMemo, useEffect } from 'react';
import addons from '@storybook/addons';
import { SET_CURRENT_STORY } from '@storybook/core-events';
import { ConfigApi } from '@storybook/client-api';

/**
 * Returns a context similar (but not identical) that can be used as an input attribute to `<DocsContainer />`
 */
const getContext = () => {
    const channel = addons.getChannel();
    //@ts-ignore
    const clientApi = window.__STORYBOOK_CLIENT_API__;
    const storyStore = clientApi._storyStore;
    const configApi = new ConfigApi({
        storyStore,
    });
    const context = {
        configApi,
        storyStore,
        channel,
        clientApi,
    };
    const { storyId } = storyStore.getSelection();
    const data = storyStore.fromId(storyId);
    const { kind, name, parameters = {} } = data || {};
    return Object.assign(Object.assign(Object.assign({}, context), data), { selectedKind: kind, selectedStory: name, parameters });
};
/**
 * function returning the current story id
 */
const getCurrentStoryId = () => {
    const selection = window &&
        //@ts-ignore
        window.__STORYBOOK_CLIENT_API__ &&
        //@ts-ignore
        window.__STORYBOOK_CLIENT_API__.store().getSelection();
    return selection ? selection.storyId : undefined;
};
/**
 * React hook hook that tracks the changes to the current story and returns it's id
 * @param defaultId initial story value, if not provided will return the current story
 * @returns a story id as a React hook, when the the current story changes, will call back
 */
const useStoryId = () => {
    const [storyId, setStoryId] = useState(getCurrentStoryId() || '.');
    const channel = useMemo(() => addons.getChannel(), []);
    useEffect(() => {
        const onStoryChange = ({ storyId: id }) => {
            setStoryId(id);
        };
        channel.on(SET_CURRENT_STORY, onStoryChange);
        return () => {
            channel.off(SET_CURRENT_STORY, onStoryChange);
        };
    }, []);
    return storyId;
};

export { getContext, getCurrentStoryId, useStoryId };
