'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var addons = _interopDefault(require('@storybook/addons'));
var coreEvents = require('@storybook/core-events');
var clientApi = require('@storybook/client-api');

/**
 * Returns a context similar (but not identical) that can be used as an input attribute to `<DocsContainer />`
 */
const getContext = () => {
    const channel = addons.getChannel();
    //@ts-ignore
    const clientApi$1 = window.__STORYBOOK_CLIENT_API__;
    const storyStore = clientApi$1._storyStore;
    const configApi = new clientApi.ConfigApi({
        storyStore,
    });
    const context = {
        configApi,
        storyStore,
        channel,
        clientApi: clientApi$1,
    };
    const { storyId } = storyStore.getSelection();
    const data = storyStore.fromId(storyId);
    const { kind, name, parameters = {} } = data || {};
    return Object.assign(Object.assign(Object.assign({}, context), data), { selectedKind: kind, selectedStory: name, parameters });
};
/**
 * function returning the current story id
 */
const getCurrentStoryId = () => {
    const selection = window &&
        //@ts-ignore
        window.__STORYBOOK_CLIENT_API__ &&
        //@ts-ignore
        window.__STORYBOOK_CLIENT_API__.store().getSelection();
    return selection ? selection.storyId : undefined;
};
/**
 * React hook hook that tracks the changes to the current story and returns it's id
 * @param defaultId initial story value, if not provided will return the current story
 * @returns a story id as a React hook, when the the current story changes, will call back
 */
const useStoryId = () => {
    const [storyId, setStoryId] = React.useState(getCurrentStoryId() || '.');
    const channel = React.useMemo(() => addons.getChannel(), []);
    React.useEffect(() => {
        const onStoryChange = ({ storyId: id }) => {
            setStoryId(id);
        };
        channel.on(coreEvents.SET_CURRENT_STORY, onStoryChange);
        return () => {
            channel.off(coreEvents.SET_CURRENT_STORY, onStoryChange);
        };
    }, []);
    return storyId;
};

exports.getContext = getContext;
exports.getCurrentStoryId = getCurrentStoryId;
exports.useStoryId = useStoryId;
